@@ -9,10 +9,24 @@
 # @Description  : 
 
 from meutils.pipe import *
+from meutils.zk_utils import get_zk_config
 from bertzoo.SimBert import SimBert, SynonymsGenerator
 from bert4keras.snippets import sequence_padding
 
-sb = SimBert('/fds/data/bert/chinese_simbert_L-12_H-768_A-12/vocab.txt')
+# BERT_DIR
+BERT_DIR = './chinese_simbert_L-12_H-768_A-12'
+fds_url = get_zk_config("/mipush/cfg")['fds_url']
+
+# todo: 如果是mice环境，选择下载解压
+if not os.path.exists(BERT_DIR):
+    url = f"{fds_url}/data/bert/chinese_simbert_L-12_H-768_A-12.zip"
+    os.system(f"wget {url} && unzip chinese_simbert_L-12_H-768_A-12.zip")
+
+config_path = f'{BERT_DIR}/bert_config.json'
+checkpoint_path = f'{BERT_DIR}/bert_model.ckpt'
+dict_path = f'{BERT_DIR}/vocab.txt'
+
+sb = SimBert(dict_path)
 
 sb.build_model()
 
@@ -53,7 +67,7 @@ logger.info(f"初始化：{gen_synonyms('支付宝', 1, 1)}")
 def gen_synonyms_(**kwargs):
     text = kwargs.get('text', '小米非常好')
     n = kwargs.get('n', 100)
-    k = kwargs.get('text', 10)
+    k = kwargs.get('k', 10)
 
     return gen_synonyms(text, n, k)
 
